@@ -10,6 +10,7 @@ import time
 import alarm
 
 JOB_DIR = os.environ['HOME'] + "/.config/alarmed/jobs/"
+PRESET_DIR = os.environ['HOME'] + "/.config/alarmed/presets/"
 
 def emptyEventInfo(self):
     """Doesn't do anything, exists only as a documentative reference"""
@@ -65,22 +66,66 @@ def loadFieldsDict():
     fields["weekdays"] = weekdays
     builtins =  {"gprsdataresetter": "Reset GPRS data counter",
                  "offlineswitcher": "Enable flight mode",
-                 "onlineswitcher": "Disable flight mode"}
+                 "onlineswitcher": "Disable flight mode",
+                 "bluetoothon": "Enable bluetooth",
+                 "bluetoothoff": "Disable bluetooth"}
     fields["builtins"] = builtins
     return fields
     
 def loadEventList():
     """Load existing events by unpickling event files"""
     eventInfos = []
-    
     if not os.path.exists(JOB_DIR):
         os.makedirs(JOB_DIR)
     for file_path in os.listdir(JOB_DIR):
-        file = open(JOB_DIR + file_path,"r")
+        file = open(JOB_DIR + file_path, "r")
         eventInfo = pickle.load(file)
         file.close()
         eventInfos.append(eventInfo)
     return eventInfos
+    
+def deleteEvent(id):
+    """Deletes an event from the alarmd queue and the config dir"""
+    alarm.delete_event(id)
+    try: os.remove(JOB_DIR + str(id))
+    except OSError:
+        return "Event file for ID " + str(id) + " does not exist"
+    return "Deleted event " + str(id)
+    
+def savePreset(preset):
+    """Saves a preset made by the user to the config dir"""
+    if not os.path.exists(PRESET_DIR):
+        os.makedirs(PRESET_DIR)
+    preset_file = open(PRESET_DIR + preset[0], "w")
+    pickle.dump(preset, preset_file)
+    preset_file.close()
+
+def deletePreset(preset):
+    """Deletes a preset from the config dir"""
+    try: os.remove(PRESET_DIR + preset[0])
+    except OSError:
+        return "Preset file for " + preset[0] + " does not exist"
+    return "Deleted preset " + preset[0]
+    
+def loadPresetList():
+    """Load existing presets by unpickling preset files"""
+    presets = []
+    if not os.path.exists(PRESET_DIR):
+        os.makedirs(PRESET_DIR)
+    for file_path in os.listdir(PRESET_DIR):
+        file = open(PRESET_DIR + file_path, "r")
+        preset = pickle.load(file)
+        file.close()
+        presets.append(preset)
+    return presets
+    
+def loadPreset(preset_name):
+    if not os.path.exists(PRESET_DIR):
+        os.makedirs(PRESET_DIR)
+    file = open(PRESET_DIR + preset_name, "r")
+    preset = pickle.load(file)
+    file.close()
+    return preset
 
 def getAvailableProfiles():
         """Checks if tweakr is installed and returns the profiles"""
@@ -208,14 +253,7 @@ def interpretDateString(string):
         return False, ("Got an error from gdate: \n" + ttime[1])
     else:
         return True, int(ttime[0].rstrip("\n"))
-
-def deleteEvent(id):
-    """Deletes an event from the alarmd queue and the config dir"""
-    alarm.delete_event(id)
-    try: os.remove(JOB_DIR + str(id))
-    except OSError:
-        return "Event file for ID " + str(id) + " does not exist"
-    return "Deleted event " + str(id)
+    
 
 def makeEvent(eventInfo, old_id):
     """Makes a new alarmd event"""
@@ -258,6 +296,12 @@ def makeEvent(eventInfo, old_id):
         elif eventInfo["content"] == b["onlineswitcher"]:
             action.command = str(
                                 "/opt/alarmed/onlineswitcher.sh normal")
+        elif eventInfo["content"] == b["bluetoothon"]:
+            action.command = str(
+                                "/opt/alarmed/bluetoothswitcher.py on")
+        elif eventInfo["content"] == b["bluetoothoff"]:
+            action.command = str(
+                                "/opt/alarmed/bluetoothswitcher.py off")
     elif eventInfo["type"] == t["profile_type"]:
         action = event.add_actions(1)[0]
         action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
