@@ -148,7 +148,7 @@ class AlarmedGUI(QtGui.QWidget):
         self.titlePicker = QtGui.QLineEdit("Enter name")
         self.row2.addWidget(self.titlePicker)
         #add button
-        self.addButton = QtGui.QPushButton("Save")
+        self.addButton = QtGui.QPushButton("Save Event")
         self.connect(self.addButton, QtCore.SIGNAL("clicked()"),
                      self.saveEvent)
         self.row2.addWidget(self.addButton)
@@ -166,6 +166,18 @@ class AlarmedGUI(QtGui.QWidget):
         self.execPicker = QtGui.QLineEdit("Enter command")
         self.row3.addWidget(self.execPicker)
         self.execPicker.hide()
+        #button for saving command to preset
+        self.execSavePresetButton = QtGui.QPushButton("Save Preset")
+        self.row3.addWidget(self.execSavePresetButton)
+        self.execSavePresetButton.hide()
+        self.connect(self.execSavePresetButton, QtCore.SIGNAL("clicked()"),
+                     self.savePreset)
+        #picker for loading presets
+        self.execPresetPicker = QtGui.QPushButton("Load Preset")
+        self.row3.addWidget(self.execPresetPicker)
+        self.execPresetPicker.hide()
+        self.connect(self.execPresetPicker, QtCore.SIGNAL("clicked()"),
+                     self.pickPreset)
 
         # If we're editing, adjust the GUI to the right values
         if (item):
@@ -176,7 +188,8 @@ class AlarmedGUI(QtGui.QWidget):
                                              item.eventInfo["schedule"])
                 self.schedulePicker.setCurrentIndex(i)
                 #update gui to fit interval type
-                self.updateScheduling(item.eventInfo["schedule"])
+                #self.updateScheduling(item.eventInfo["schedule"])
+                self.updateScheduling(0)
             except KeyError: pass
             #adjust type
             try:
@@ -199,7 +212,7 @@ class AlarmedGUI(QtGui.QWidget):
             #~ self.rWeekdayPicker.setCurrentIndex(
              #~ item.eventInfo["weekday"])
             #adjust number of steps
-            try: self.numberPicker.setValue(item.eventInfo["number"])
+            try: self.numberPicker.setValue(int(item.eventInfo["number"]))
             except KeyError: pass
             #adjust type of step
             try: i = self.intervalPicker.findText(
@@ -224,6 +237,7 @@ class AlarmedGUI(QtGui.QWidget):
             self.editing = True
         else:
             self.editing = False
+        self.updateScheduling(0)
         self.newEventDialog.open()
 
     def updateInputField(self, index):
@@ -233,18 +247,26 @@ class AlarmedGUI(QtGui.QWidget):
         if type == t["alarm_type"]:
             self.execPicker.hide()
             self.builtinPicker.hide()  
-            self.profilePicker.hide()  
+            self.profilePicker.hide() 
+            self.execSavePresetButton.hide() 
+            self.execPresetPicker.hide() 
         elif type == t["exec_type"]:
             self.builtinPicker.hide()
             self.execPicker.show()
             self.profilePicker.hide()
+            self.execSavePresetButton.show()
+            self.execPresetPicker.show()
         elif type == t["builtin_type"]:
             self.execPicker.hide()
             self.builtinPicker.show()
             self.profilePicker.hide()
+            self.execSavePresetButton.hide() 
+            self.execPresetPicker.hide() 
         elif type == t["profile_type"]:
             self.execPicker.hide()
             self.builtinPicker.hide()
+            self.execSavePresetButton.hide() 
+            self.execPresetPicker.hide() 
             self.profilePicker.show()
             self.profilePicker.clear()
             profiles = alarmed_backend.getAvailableProfiles()
@@ -261,6 +283,8 @@ class AlarmedGUI(QtGui.QWidget):
         elif type == t["exec_type"]:
             self.execPicker.setText(content)
             self.execPicker.show()
+            self.execSavePresetButton.show()
+            self.execPresetPicker.show()
         elif type == t["profile_type"]:
             self.profilePicker.clear()
             profiles = alarmed_backend.getAvailableProfiles()
@@ -273,7 +297,7 @@ class AlarmedGUI(QtGui.QWidget):
             self.profilePicker.setCurrentIndex(i)
             self.profilePicker.show()
 
-    def updateScheduling(self, schedule):
+    def updateScheduling(self, index):
         """Updates the GUI to fit the current schedule type"""
         schedule = self.schedulePicker.currentText()
         s = self.fields["schedules"]
@@ -369,6 +393,67 @@ class AlarmedGUI(QtGui.QWidget):
             self.timePicker.hide()
             self.cronPicker.hide()
             self.datesyntaxPicker.show()
+            
+    def pickPreset(self):
+        """Dialog for loading and deleting presets"""
+        self.presetDialog = QtGui.QDialog()
+        self.presetDialog.setWindowTitle("Load or delete presets")
+        self.presetDialogVBox = QtGui.QVBoxLayout()
+        self.presetDialogHBox = QtGui.QHBoxLayout()
+        # the list of presets on the right side
+        self.presetList = QtGui.QListWidget()
+        self.presetList.setSelectionMode(
+                     QtGui.QAbstractItemView.SingleSelection)
+        self.loadPresetList()
+        self.presetDialogHBox.addWidget(self.presetList)
+        # the add and pick buttons on the right
+        self.presetPickButton = QtGui.QPushButton("Use preset")
+        self.connect(self.presetPickButton, QtCore.SIGNAL("clicked()"),
+                     self.usePreset)
+        self.presetDeleteButton = QtGui.QPushButton("Delete preset")
+        self.connect(self.presetDeleteButton, QtCore.SIGNAL("clicked()"),
+                     self.deletePreset)
+        self.presetDialogVBox.addWidget(self.presetPickButton)
+        self.presetDialogVBox.addWidget(self.presetDeleteButton)
+        self.presetDialogHBox.addLayout(self.presetDialogVBox)
+        self.presetDialog.setLayout(self.presetDialogHBox)
+        self.presetDialog.exec_()
+    
+    def loadPresetList(self):
+        self.presetList.clear()
+        presets = alarmed_backend.loadPresetList()
+        for preset in presets:
+            addedPreset = QtGui.QListWidgetItem(preset[0])
+            addedPreset.preset = preset
+            self.presetList.addItem(addedPreset)
+    
+    def usePreset(self):
+        if (self.presetList.currentItem()):
+            self.titlePicker.setText(
+                                self.presetList.currentItem().preset[0])
+            self.execPicker.setText(
+                                self.presetList.currentItem().preset[1])
+            self.presetDialog.accept()
+        else:
+            self.showError('''<font color="#000000">Select an item first</font>''')
+        
+    def deletePreset(self):
+        """Calls backend to remove a preset """
+        if (self.presetList.currentItem()):
+            alarmed_backend.deletePreset(
+                            self.presetList.currentItem().preset)
+            self.presetList.removeItemWidget(
+                            self.presetList.currentItem())
+            self.loadPresetList()
+        else:
+            self.showError('''<font color="#000000">Select an item first</font>''')
+
+    def savePreset(self):
+        preset = []
+        preset.append(str(self.titlePicker.text()))
+        preset.append(str(self.execPicker.text()))
+        alarmed_backend.savePreset(preset)
+        self.showError('''<font color="#000000">Preset saved</font>''')
 
     def pickWeekdays(self):
         """Presents 7 checkboxes to select days"""
